*$ CREATE GSROC.FOR
*COPY GSROC
*
*=== GSROC ===========================================================*
*
c================================================================
      DOUBLE PRECISION FUNCTION GSROC(TET,FI)
c ===============================================================
c
c       tet  is zenith
c       fi   is azimuth
c       azimuth=0. north direction   (clockwise)
c       zenith=0.  vertical
c
c       dgsm(i,j) is the depth in metres
c                 i=1,48         i= 1 for   zenith=  0. deg
c                                i=48 for   zenith= 94. deg
c                 j=1,91         j= 1 for  azimuth=  0. deg
c                                j=91 for  azimuth=360. deg
c       gsroc is the depth in metres in (tet,fi) direction
c       azimuth angle is corrected for the difference between
c       UTM projection and the geographic coordinates.
c       the result gsroc=-999999. means that tet is greater than 94 deg
c       or/and fi is greater than 360 deg
c =======================================================================
c
      INCLUDE '(DBLPRC)'
      INCLUDE '(DIMPAR)'
      INCLUDE '(IOUNIT)'
      INCLUDE 'map_96_center.inc'
C
      GSROC=-999999.
C
      IFLAG=1
C
      JT=TET/2.+1
      JF=FI/4.+1
      IF(JT.GE.48.OR.JF.GE.91)GO TO 300
C
      D1=DGSM(JT,JF)
      D2=DGSM(JT+1,JF)
      D3=DGSM(JT,JF+1)
      D4=DGSM(JT+1,JF+1)
C
C     GSROC > 100000: TRACK PUNCHES THE MOUNTAIN OUTSIDE THE ELEVATION
C     MAP. iN THIS CASE DEPTH IS GREATER THAN CALCULATED VALUE:
C     (GSROC-100000.)
C
      IF(D1.GT.100000..OR.D2.GT.100000..OR.D3.GT.100000..OR.D4.GT
     *.100000.)IFLAG=-1
      IF(D1.GT.100000.)D1=D1-100000.
      IF(D2.GT.100000.)D2=D2-100000.
      IF(D3.GT.100000.)D3=D3-100000.
      IF(D4.GT.100000.)D4=D4-100000.
C
      T1=2.*(JT-1)
      F1=4.*(JF-1)
C
      R=(TET-T1)/2
      U=(FI-F1)/4.
C
      GSROC=(1.-R)*(1.-U)*D1+R*(1.-U)*D2+(1.-R)*U*D3+R*U*D4
C
  100 CONTINUE
C
      IF(IFLAG.LT.1)GSROC=GSROC+100000.
C
  300 RETURN
      END

